use crate::{
    app::session::SessionToken,
    util::pack::pack_u16,
};

use super::Packet;

#[derive(Clone)]
pub struct PacketSessionJoin {
    pub token:SessionToken,
    pub join:bool,
}
impl PacketSessionJoin {
    pub fn new() -> Self
    {
        Self {
            token:SessionToken::default(),
            join:false,
        }
    }
}
impl Packet for PacketSessionJoin {
    type Data = Self;

    fn decode(data:&Vec<u8>, index:&mut usize) -> Result<Self::Data, ()>
    {
        let mut result = Self::new();

        if data.len() - *index == 9 {
            for i in 0..8 { result.token[i] = data[*index]; *index += 1; }
            result.join = data[*index] != 0;
            Ok(result)
        } else {
            Err(())
        }
    }
}


#[derive(Clone)]
pub struct PacketSessionJoinResponse {
    pub status:u16,
    pub token:SessionToken,
}
impl PacketSessionJoinResponse {
    pub fn new() -> Self
    {
        Self {
            status:0,
            token:SessionToken::default(),
        }
    }
}
impl Packet for PacketSessionJoinResponse {
    type Data = Self;

    fn encode(&self) -> Vec<u8>
    {
        [
            pack_u16(self.status),
            self.token.to_vec(),
        ].concat()
    }
}
